package com.ningdatech.pmapi.declared.controller;

import com.ningdatech.basic.model.PageVo;
import com.ningdatech.pmapi.declared.entity.dto.DeclaredProjectParamDto;
import com.ningdatech.pmapi.declared.manage.DeclaredProjectManage;
import com.wflow.bean.vo.NdDeclaredProjectVo;
import com.wflow.workflow.bean.vo.ProcessStartParamsVo;
import com.wflow.workflow.service.ProcessInstanceService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

/**
 * @Classname DeclaredProjectController
 * @Description 申报项目
 * @Date 2023/1/31 11:29
 * @Author PoffyZhang
 */
@Slf4j
@Validated
@RestController
@RequestMapping("/api/v1/declared")
@Api(value = "DeclaredProject", tags = "申报管理-申报项目")
@RequiredArgsConstructor
public class DeclaredProjectController {
    private final ProcessInstanceService processService;

    private final DeclaredProjectManage declaredProjectManage;

    @ApiOperation(value = "申报项目已申报列表", notes = "申报项目已申报列表")
    @GetMapping("/list")
    public PageVo<NdDeclaredProjectVo> list(@Validated @ModelAttribute DeclaredProjectParamDto params) {;
        return declaredProjectManage.page(params);
    }

    @ApiOperation(value = "申报项目草稿箱", notes = "申报项目草稿箱")
    @GetMapping("/draft")
    public PageVo<NdDeclaredProjectVo> draft(@Validated @ModelAttribute ProcessStartParamsVo params) {
        return PageVo.empty();
    }

    @ApiOperation(value = "申报项目", notes = "申报项目")
    @PostMapping("/start/{defId}")
    public String startTheProcess(@PathVariable String defId,
                                  @RequestBody ProcessStartParamsVo params) {
        String instanceId = processService.startProcess(defId, params);
        return "启动流程实例 " + instanceId + " 成功";
    }

}
