package com.ningdatech.pmapi.projectlib.manage;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ningdatech.basic.model.PageVo;
import com.ningdatech.basic.util.CollUtils;
import com.ningdatech.pmapi.projectlib.model.req.ProjectLibListReq;
import com.ningdatech.pmapi.projectlib.model.vo.ProjectLibListItemVO;
import com.wflow.bean.entity.NdDeclaredProject;
import com.wflow.service.NdDeclaredProjectService;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.stream.Collectors;

import static com.ningdatech.pmapi.common.utils.BizUtils.notBlank;
import static com.ningdatech.pmapi.common.utils.BizUtils.notNull;

/**
 * <p>
 * ProjectLibManage
 * </p>
 *
 * @author WendyYang
 * @since 14:19 2023/2/1
 */
@Component
@RequiredArgsConstructor
public class ProjectLibManage {

    private final NdDeclaredProjectService declaredProjectService;

    private LambdaQueryWrapper<NdDeclaredProject> projectLibQuery(ProjectLibListReq req) {
        LambdaQueryWrapper<NdDeclaredProject> query = Wrappers.lambdaQuery(NdDeclaredProject.class);
        notBlank(req.getProjectName(), w -> query.like(NdDeclaredProject::getProjectName, w));
        notNull(req.getProjectType(), w -> query.eq(NdDeclaredProject::getProjectType, w));
        notNull(req.getProjectYear(), w -> query.eq(NdDeclaredProject::getProjectYear, w));
        // 申报金额 批复金额
        notNull(req.getApprovedAmountMin(), w -> query.ge(NdDeclaredProject::getApprovedAmount, w));
        notNull(req.getApprovedAmountMax(), w -> query.le(NdDeclaredProject::getApprovedAmount, w));

        notNull(req.getDeclaredAmountMax(), w -> query.le(NdDeclaredProject::getDeclaredAmount, w));
        notNull(req.getDeclaredAmountMin(), w -> query.ge(NdDeclaredProject::getDeclaredAmount, w));
        // 状态查询
        notNull(req.getStatus1st(), w -> query.ge(NdDeclaredProject::getProjectStatusFirst, w));
        notNull(req.getStatus2nd(), w -> query.ge(NdDeclaredProject::getProjectStatusSecond, w));

        notNull(req.getCreateOnMin(), w -> query.ge(NdDeclaredProject::getCreateOn, w));
        notNull(req.getCreateOnMax(), w -> query.le(NdDeclaredProject::getCreateOn, w));

        notBlank(req.getApplyOrg(), w -> query.like(NdDeclaredProject::getOrgName, w));

        query.orderByDesc(NdDeclaredProject::getUpdateOn, NdDeclaredProject::getCreateOn);
        // TODO 区域编码处理
        return query;
    }

    public PageVo<ProjectLibListItemVO> projectLibList(ProjectLibListReq req) {
        LambdaQueryWrapper<NdDeclaredProject> query = projectLibQuery(req);
        Page<NdDeclaredProject> page = declaredProjectService.page(req.page(), query);
        long total;
        if ((total = page.getTotal()) == 0) {
            return PageVo.empty();
        }
        List<ProjectLibListItemVO> records = CollUtils.convert(page.getRecords(), w -> {
            ProjectLibListItemVO item = new ProjectLibListItemVO();
            item.setId(w.getId());
            item.setProjectName(w.getProjectName());
            item.setCreateOn(w.getCreateOn());
            item.setDeclaredAmount(w.getDeclaredAmount());
            item.setStatus1st(w.getProjectStatusFirst());
            item.setStatus2nd(w.getProjectStatusSecond());
            item.setProjectType(w.getProjectType());
            item.setProjectYear(w.getProjectYear());
            item.setApplyOrg(w.getOrgName());
            item.setBizArea(w.getBizArea());
            return item;
        });
        return PageVo.of(records, total);
    }

}
